==> webpdf-wsclient-9.0.1-sources.jar: net/webpdf/wsclient/schema/extraction/barcode/BarcodesType.java <==

package net.webpdf.wsclient.schema.extraction.barcode;

import java.util.ArrayList;
import java.util.List;
import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlElement;
import jakarta.xml.bind.annotation.XmlRootElement;
import jakarta.xml.bind.annotation.XmlType;


/**
 * <p>Java class for barcodes element declaration.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>{@code
 * <element name="barcodes">
 *   <complexType>
 *     <complexContent>
 *       <restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *         <sequence maxOccurs="unbounded">
 *           <element name="barcode" type="{http://schema.webpdf.de/1.0/extraction/barcode}BarcodeType"/>
 *         </sequence>
 *       </restriction>
 *     </complexContent>
 *   </complexType>
 * </element>
 * }</pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "barcode"
})
@XmlRootElement(name = "barcodes")
public class BarcodesType {

    @XmlElement(required = true)
    protected List<BarcodeType> barcode;

    /**
     * Gets the value of the barcode property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the Jakarta XML Binding object.
     * This is why there is not a {@code set} method for the barcode property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getBarcode().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link BarcodeType }
     * 
     * 
     * @return
     *     The value of the barcode property.
     */
    public List<BarcodeType> getBarcode() {
        if (barcode == null) {
            barcode = new ArrayList<>();
        }
        return this.barcode;
    }

    public boolean isSetBarcode() {
        return ((this.barcode!= null)&&(!this.barcode.isEmpty()));
    }

    public void unsetBarcode() {
        this.barcode = null;
    }

}

==> webpdf-wsclient-9.0.2-sources.jar: net/webpdf/wsclient/schema/extraction/barcode/BarcodesType.java <==

package net.webpdf.wsclient.schema.extraction.barcode;

import java.util.ArrayList;
import java.util.List;
import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlElement;
import jakarta.xml.bind.annotation.XmlRootElement;
import jakarta.xml.bind.annotation.XmlType;


/**
 * <p>Java class for barcodes element declaration</p>.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.</p>
 * 
 * <pre>{@code
 * <element name="barcodes">
 *   <complexType>
 *     <complexContent>
 *       <restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *         <sequence maxOccurs="unbounded">
 *           <element name="barcode" type="{http://schema.webpdf.de/1.0/extraction/barcode}BarcodeType"/>
 *         </sequence>
 *       </restriction>
 *     </complexContent>
 *   </complexType>
 * </element>
 * }</pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "barcode"
})
@XmlRootElement(name = "barcodes")
public class BarcodesType {

    @XmlElement(required = true)
    protected List<BarcodeType> barcode;

    /**
     * Gets the value of the barcode property.
     * 
     * <p>This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the barcode property.</p>
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * </p>
     * <pre>
     * getBarcode().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link BarcodeType }
     * </p>
     * 
     * 
     * @return
     *     The value of the barcode property.
     */
    public List<BarcodeType> getBarcode() {
        if (barcode == null) {
            barcode = new ArrayList<>();
        }
        return this.barcode;
    }

    public boolean isSetBarcode() {
        return ((this.barcode!= null)&&(!this.barcode.isEmpty()));
    }

    public void unsetBarcode() {
        this.barcode = null;
    }

}
